import os
import datetime

class Singleton(type):
    _instances = {}

    def __call__(cls, *args, **kwargs):
        if cls not in cls._instances:
            cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
        return cls._instances[cls]


class CtrlCraftSimulator(object, metaclass=Singleton):

    def gate_clear(self):

        dirname = os.path.dirname(os.path.realpath(__file__))
        csv = os.path.join(dirname, 'gate.csv')

        if os.path.isfile(csv):
            os.remove(csv)

    def gate_create(self, deposit, panel, blast, truck):
        """
        Creates a new entry in the gate file.
        """

        dirname = os.path.dirname(os.path.realpath(__file__))
        csv = os.path.join(dirname, 'gate.csv')

        if not os.path.isfile(csv):
            with open(csv, 'w') as csvfile:
                header = 'deposit,panel,blast,truck,date,time,radiometry\n'
                csvfile.write(header)

        nline = -1  # always a header
        with open(csv, 'r') as csvfile:
            for line in csvfile:
                nline += 1

        with open(csv, 'a') as csvfile:
            now = datetime.datetime.now()

            date = '{}/{}/{}'.format(now.year, now.month, now.day)

            minute = '{}'.format(now.minute)
            if len(minute) == 1:
                minute = '0{}'.format(minute)

            time = '{}h{}'.format(now.hour, minute)

            radiometry = '0.{}'.format(nline)
            line = ('{},{},{},{},{},{},{}\n'
                    .format(deposit, panel, blast, truck, date, time,
                            radiometry))
            csvfile.write(line)
